@@ -3,20 +3,36 @@ Typed settings
 """
 from typing import Any, List
 
-from ._core import load, load_settings
+from ._core import default_loaders, load, load_settings
 from ._file_utils import find
-from .attrs import option, secret, settings
+from .attrs import combine, evolve, option, secret, settings
+from .converters import default_converter, register_strlist_hook
+from .loaders import EnvLoader, FileLoader, TomlFormat
 
 
 __all__ = [
-    "click_options",
-    "find",
+    # Core
+    "default_loaders",
     "load",
     "load_settings",
+    # File utils
+    "find",
+    # Loaders
+    "EnvLoader",
+    "FileLoader",
+    "TomlFormat",
+    # Attrs helpers
+    "combine",
+    "evolve",
     "option",
-    "pass_settings",
     "secret",
     "settings",
+    # Cattrs converters/helpers
+    "default_converter",
+    "register_strlist_hook",
+    # Click utils
+    "click_options",
+    "pass_settings",
 ]
 
 
